@@ -10,14 +10,9 @@
 
 package Main;
 
-#use File::FindLib 'lib';
-
 use Moose;
-#use Carp::Always;
-#use Data::Dumper;
-
 extends 'Runner::Threads';
 
-Runner::Threads->new_with_options()->go;
+Main->new_with_options()->go;
 
 1;
